@@ -1,6 +1,9 @@
 """Policy for MAGE using PyTorch."""
 from typing import List, Tuple
 
+from nnrl.nn.critic import HardValue
+from nnrl.optim import build_optimizer
+
 from raylab.agents.sop import SOPTorchPolicy
 from raylab.options import configure, option
 from raylab.policy import EnvFnMixin
@@ -8,8 +11,6 @@ from raylab.policy.action_dist import WrapDeterministicPolicy
 from raylab.policy.losses import MAGE, MaximumLikelihood
 from raylab.policy.model_based.lightning import LightningModelTrainer, TrainingSpec
 from raylab.policy.model_based.policy import MBPolicyMixin
-from raylab.policy.modules.critic import HardValue
-from raylab.torch.optim import build_optimizer
 from raylab.utils.types import StatDict
 
 
