@@ -1,5 +1,9 @@
 """SOP policy class using PyTorch."""
 import torch
+from nnrl.nn.critic import HardValue
+from nnrl.nn.utils import update_polyak
+from nnrl.optim import build_optimizer
+from nnrl.types import TensorDict
 from ray.rllib.utils import override
 from torch.nn.utils import clip_grad_norm_
 
@@ -7,11 +11,7 @@ from raylab.options import configure, option
 from raylab.policy import TorchPolicy
 from raylab.policy.action_dist import WrapDeterministicPolicy
 from raylab.policy.losses import ActionDPG, DeterministicPolicyGradient, FittedQLearning
-from raylab.policy.modules.critic import HardValue
 from raylab.policy.off_policy import OffPolicyMixin
-from raylab.torch.nn.utils import update_polyak
-from raylab.torch.optim import build_optimizer
-from raylab.utils.types import TensorDict
 
 
 @configure
