@@ -505,6 +505,14 @@ COMMON_INFO = {
     """,
     "env": """\
     Environment name can also be passed via config.""",
+    "observation_space": """\
+    The observation- and action spaces for the Policies of this Trainer.
+    Use None for automatically inferring these from the given env.
+    """,
+    "action_space": """\
+    The observation- and action spaces for the Policies of this Trainer.
+    Use None for automatically inferring these from the given env.
+    """,
     "normalize_actions": """\
     Unsquash actions to the upper and lower bounds of env's action space""",
     "clip_rewards": """\
@@ -725,6 +733,15 @@ COMMON_INFO = {
      - a dict with string keys and sampling probabilities as values (e.g.,
        {"sampler": 0.4, "/tmp/*.json": 0.4, "s3://bucket/expert.json": 0.2}).
      - a function that returns a rllib.offline.InputReader""",
+    "input_config": """\
+    Arguments accessible from the IOContext for configuring custom input
+    """,
+    "actions_in_input_normalized": """\
+    True, if the actions in a given offline "input" are already normalized
+    (between -1.0 and 1.0). This is usually the case when the offline
+    file has been generated by another RLlib algorithm (e.g. PPO or SAC),
+    while "normalize_actions" was set to True.
+    """,
     "input_evaluation": """\
     Specify how to evaluate the current policy. This only has an effect when
     reading offline experiences. Available options:
