@@ -2,14 +2,14 @@
 from typing import Tuple
 
 import torch
-import torch.nn as nn
+from nnrl.nn.actor import Alpha, StochasticPolicy
+from nnrl.nn.critic import VValue
+from nnrl.types import TensorDict
 from ray.rllib import SampleBatch
 from ray.rllib.utils import override
-from torch import Tensor
+from torch import Tensor, nn
 
-from raylab.policy.modules.actor import Alpha, StochasticPolicy
-from raylab.policy.modules.critic import VValue
-from raylab.utils.types import StatDict, TensorDict
+from raylab.utils.types import StatDict
 
 from .abstract import Loss
 
