@@ -2,11 +2,12 @@
 from typing import Callable, Tuple
 
 import torch
+from nnrl.nn.actor import StochasticPolicy
+from nnrl.types import TensorDict
 from ray.rllib import SampleBatch
 from torch import Tensor
 
-from raylab.policy.modules.actor import StochasticPolicy
-from raylab.utils.types import StatDict, TensorDict
+from raylab.utils.types import StatDict
 
 from .abstract import Loss
 
