@@ -1,12 +1,11 @@
 """Architecture used in Trust Region Policy Optimization."""
 from dataclasses import dataclass, field
 
-import torch.nn as nn
 from dataclasses_json import DataClassJsonMixin
 from gym.spaces import Box
-
-from .actor import StochasticActor
-from .critic import MLPVValue
+from nnrl.nn.actor import StochasticActor
+from nnrl.nn.critic import MLPVValue
+from torch import nn
 
 ActorSpec = StochasticActor.spec_cls
 CriticSpec = MLPVValue.spec_cls
