@@ -2,8 +2,7 @@
 From Proximal Policy Optimization Algorithms:
 http://arxiv.org/abs/1707.06347
 """
-from dataclasses import dataclass
-from dataclasses import field
+from dataclasses import dataclass, field
 
 
 @dataclass
