@@ -1,8 +1,7 @@
 # pylint:disable=missing-module-docstring
+import nnrl.utils as ptu
 import numpy as np
 
-import raylab.torch.utils as ptu
-
 from .base import BaseExploration, Model
 
 
